utils Package
=============

:mod:`handlers` Module
----------------------

.. automodule:: permission.utils.handlers
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`logics` Module
--------------------

.. automodule:: permission.utils.logics
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`permissions` Module
-------------------------

.. automodule:: permission.utils.permissions
    :members:
    :undoc-members:
    :show-inheritance:

